@@ -21,9 +21,7 @@
 #'        returns 0.95% confidence intervals. By default, sign_level = 0.05.
 #' @param conf_int A logical vector. If TRUE, boottest computes confidence 
 #'        intervals by p-value inversion. If FALSE, only the p-value is returned.
-#' @param seed An integer. Allows the user to set a random seed. If NULL, `boottest()` sets an
-#'        internal seed. Hence by default, calling `boottest()` multiple times on the same object will produce 
-#'        the same test statistics.
+#' @param seed An integer. Allows the user to set a random seed. If you want to set a "global" seed, set it via `dqrng::dqset.seed()`.
 #' @param R Hypothesis Vector giving linear combinations of coefficients. Must be either NULL or a vector of the same length as `param`. If NULL, a vector of ones of length param.
 #' @param beta0 A numeric. Shifts the null hypothesis 
 #'        H0: param = beta0 vs H1: param != beta0
@@ -31,7 +29,7 @@
 #'        of boostrap to use: One of "rademacher", "mammen", "norm"
 #'        and "webb". Alternatively, type can be a function(n) for drawing 
 #'        wild bootstrap factors. "rademacher" by default.  
-#'        For the Rademacher and Mammen distribution, if the number of replications B exceeds 
+#'        For the Rademacher distribution, if the number of replications B exceeds 
 #'        the number of possible draw ombinations, 2^(#number of clusters), then `boottest()` 
 #'        will use each possible combination once (enumeration).
 #' @param impose_null Logical. Controls if the null hypothesis is imposed on
@@ -170,8 +168,8 @@ boottest.lm <- function(object,
   # check appropriateness of nthreads
   nthreads <- check_set_nthreads(nthreads)
   
-  if(is.null(seed)){
-    seed <- 1
+  if(!is.null(seed)){
+    dqrng::dqset.seed(seed)
   }
   
   if(maxiter < 1){
@@ -269,7 +267,7 @@ boottest.lm <- function(object,
   # number of clusters used in bootstrap - always derived from bootcluster
   N_G <- length(unique(preprocess$bootcluster[, 1]))
   N_G_2 <- 2^N_G
-  if (type %in% c("rademacher", "mammen") & N_G_2 < B) {
+  if (type %in% c("rademacher") & N_G_2 < B) {
     warning(paste("There are only", N_G_2, "unique draws from the rademacher distribution for", length(unique(preprocess$bootcluster[, 1])), "clusters. Therefore, B = ", N_G_2, " with full enumeration. Consider using webb weights instead."),
             call. = FALSE, 
             noBreaks. = TRUE
@@ -293,7 +291,7 @@ boottest.lm <- function(object,
                     beta0 = beta0,
                     sign_level = sign_level,
                     param = param,
-                    seed = seed,
+                    # seed = seed,
                     p_val_type = p_val_type, 
                     nthreads = nthreads, 
                     type = type, 
