@@ -46,32 +46,32 @@ boot_fixest_c <- suppressWarnings(boottest(object = feols_fit_c, clustid = c("gr
 boot_felm_c <- suppressWarnings(boottest(object = felm_fit_c, clustid =  "group_id1", B = 999, seed = 911, param = "treatment", conf_int = TRUE))
 
 # point estimates
-expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate)
+expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate)
+expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate)
+expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate)
+expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate)
 
 # p-vals
-expect_equivalent(boot_lm$p_val, boot_fixest$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest$p_val, boot_felm$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_c$p_val, boot_lm$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest$p_val)
+expect_equivalent(boot_fixest$p_val, boot_felm$p_val)
+expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val)
+expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val)
+expect_equivalent(boot_felm_c$p_val, boot_lm$p_val)
 
 # t_stats
-expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat)
+expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat)
+expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat)
+expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat)
+expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat)
 
 # confidence intervals
-expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int)
+expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int)
+expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int)
+expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int)
+expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int)
 
 
 
@@ -80,7 +80,7 @@ expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
 # ---------------------------------------------------------------------------------------------- # 
 # Part B1: one fixed effect in model
 
-lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration , 
+lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + as.factor(Q1_immigration) , 
              data = fwildclusterboot:::create_data(N = 1000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration, 
                            data = fwildclusterboot:::create_data(N = 1000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
@@ -104,52 +104,52 @@ boot_fixest_c_fe <- suppressWarnings(boottest(object = feols_fit_c, clustid = c(
 boot_felm_c_fe <- suppressWarnings(boottest(object = felm_fit_c, clustid =  "group_id1", fe = "Q1_immigration", B = 999, seed = 911, param = "treatment", conf_int = TRUE))
 
 # point estimates
-expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate)
+expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate)
+expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate)
+expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate)
+expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate)
 
-expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate)
+expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate)
+expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate)
+expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate)
 
 # p-vals
-expect_equivalent(boot_lm$p_val, boot_fixest$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest$p_val, boot_felm$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_c$p_val, boot_lm$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest$p_val)
+expect_equivalent(boot_fixest$p_val, boot_felm$p_val)
+expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val)
+expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val)
+expect_equivalent(boot_felm_c$p_val, boot_lm$p_val)
 
-expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val)
+expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val)
+expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val)
+expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val)
 
 # t_stats
-expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat)
+expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat)
+expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat)
+expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat)
+expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat)
 
-expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat)
+expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat)
+expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat)
+expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat)
 
 # confidence intervals
-expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int)
+expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int)
+expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int)
+expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int)
+expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int)
 
-expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int)
+expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int)
+expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int)
+expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int)
 
 
 
@@ -182,52 +182,52 @@ boot_felm_c_fe <- suppressWarnings(boottest(object = felm_fit_c, clustid =  "gro
 
 
 # point estimates
-expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate)
+expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate)
+expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate)
+expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate)
+expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate)
 
-expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate)
+expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate)
+expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate)
+expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate)
 
 # p-vals
-expect_equivalent(boot_lm$p_val, boot_fixest$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest$p_val, boot_felm$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_c$p_val, boot_lm$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest$p_val)
+expect_equivalent(boot_fixest$p_val, boot_felm$p_val)
+expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val)
+expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val)
+expect_equivalent(boot_felm_c$p_val, boot_lm$p_val)
 
-expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val)
+expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val)
+expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val)
+expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val)
 
 # t_stats
-expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat)
+expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat)
+expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat)
+expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat)
+expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat)
 
-expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat)
+expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat)
+expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat)
+expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat)
 
 # confidence intervals
-expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int)
+expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int)
+expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int)
+expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int)
+expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int)
 
-expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int)
+expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int)
+expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int)
+expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int)
 
 
 # ---------------------------------------------------------------------------------------------- # 
@@ -256,32 +256,32 @@ boot_fixest_c <- suppressWarnings(boottest(object = feols_fit_c, clustid = c("gr
 boot_felm_c <- suppressWarnings(boottest(object = felm_fit_c, clustid =  "group_id1", B = 999, seed = 911, param = "treatment", conf_int = TRUE))
 
 # point estimates
-expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate)
+expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate)
+expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate)
+expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate)
+expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate)
 
 # p-vals
-expect_equivalent(boot_lm$p_val, boot_fixest$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest$p_val, boot_felm$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_c$p_val, boot_lm$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest$p_val)
+expect_equivalent(boot_fixest$p_val, boot_felm$p_val)
+expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val)
+expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val)
+expect_equivalent(boot_felm_c$p_val, boot_lm$p_val)
 
 # t_stats
-expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat)
+expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat)
+expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat)
+expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat)
+expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat)
 
 # confidence intervals
-expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int)
+expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int)
+expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int)
+expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int)
+expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int)
 
 
 
@@ -314,52 +314,52 @@ boot_fixest_c_fe <- suppressWarnings(boottest(object = feols_fit_c, clustid = c(
 boot_felm_c_fe <- suppressWarnings(boottest(object = felm_fit_c, clustid =  "group_id1", fe = "Q1_immigration", B = 999, seed = 911, param = "treatment", conf_int = TRUE))
 
 # point estimates
-expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate)
+expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate)
+expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate)
+expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate)
+expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate)
 
-expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate)
+expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate)
+expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate)
+expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate)
 
 # p-vals
-expect_equivalent(boot_lm$p_val, boot_fixest$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest$p_val, boot_felm$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_c$p_val, boot_lm$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest$p_val)
+expect_equivalent(boot_fixest$p_val, boot_felm$p_val)
+expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val)
+expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val)
+expect_equivalent(boot_felm_c$p_val, boot_lm$p_val)
 
-expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val)
+expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val)
+expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val)
+expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val)
 
 # t_stats
-expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat)
+expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat)
+expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat)
+expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat)
+expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat)
 
-expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat)
+expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat)
+expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat)
+expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat)
 
 # confidence intervals
-expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int)
+expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int)
+expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int)
+expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int)
+expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int)
 
-expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int)
+expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int)
+expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int)
+expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int)
 
 
 
@@ -392,51 +392,52 @@ boot_felm_c_fe <- suppressWarnings(boottest(object = felm_fit_c, clustid =  "gro
 
 
 # point estimates
-expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest$point_estimate)
+expect_equivalent(boot_fixest$point_estimate, boot_felm$point_estimate)
+expect_equivalent(boot_felm$point_estimate, boot_fixest_c$point_estimate)
+expect_equivalent(boot_fixest_c$point_estimate, boot_felm_c$point_estimate)
+expect_equivalent(boot_felm_c$point_estimate, boot_lm$point_estimate)
 
-expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate, tolerance = 0.1)
+expect_equivalent(boot_lm$point_estimate, boot_fixest_fe$point_estimate)
+expect_equivalent(boot_fixest_fe$point_estimate, boot_felm_fe$point_estimate)
+expect_equivalent(boot_felm_fe$point_estimate, boot_fixest_c_fe$point_estimate)
+expect_equivalent(boot_fixest_c_fe$point_estimate, boot_felm_c_fe$point_estimate)
 
 # p-vals
-expect_equivalent(boot_lm$p_val, boot_fixest$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest$p_val, boot_felm$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_c$p_val, boot_lm$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest$p_val)
+expect_equivalent(boot_fixest$p_val, boot_felm$p_val)
+expect_equivalent(boot_felm$p_val, boot_fixest_c$p_val)
+expect_equivalent(boot_fixest_c$p_val, boot_felm_c$p_val)
+expect_equivalent(boot_felm_c$p_val, boot_lm$p_val)
 
-expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val, tolerance = 0.1)
+expect_equivalent(boot_lm$p_val, boot_fixest_fe$p_val)
+expect_equivalent(boot_fixest_fe$p_val, boot_felm_fe$p_val)
+expect_equivalent(boot_felm_fe$p_val, boot_fixest_c_fe$p_val)
+expect_equivalent(boot_fixest_c_fe$p_val, boot_felm_c_fe$p_val)
 
 # t_stats
-expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest$t_stat)
+expect_equivalent(boot_fixest$t_stat, boot_felm$t_stat)
+expect_equivalent(boot_felm$t_stat, boot_fixest_c$t_stat)
+expect_equivalent(boot_fixest_c$t_stat, boot_felm_c$t_stat)
+expect_equivalent(boot_felm_c$t_stat, boot_lm$t_stat)
 
-expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat, tolerance = 0.1)
+expect_equivalent(boot_lm$t_stat, boot_fixest_fe$t_stat)
+expect_equivalent(boot_fixest_fe$t_stat, boot_felm_fe$t_stat)
+expect_equivalent(boot_felm_fe$t_stat, boot_fixest_c_fe$t_stat)
+expect_equivalent(boot_fixest_c_fe$t_stat, boot_felm_c_fe$t_stat)
 
 # confidence intervals
-expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
+expect_equivalent(boot_lm$conf_int, boot_fixest$conf_int)
+expect_equivalent(boot_fixest$conf_int, boot_felm$conf_int)
+expect_equivalent(boot_felm$conf_int, boot_fixest_c$conf_int)
+expect_equivalent(boot_fixest_c$conf_int, boot_felm_c$conf_int)
+expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int)
+
+expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int)
+expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int)
+expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int)
+expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int)
 
-expect_equivalent(boot_lm$conf_int, boot_fixest_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_fe$conf_int, boot_felm_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_felm_fe$conf_int, boot_fixest_c_fe$conf_int, tolerance = 0.1)
-expect_equivalent(boot_fixest_c_fe$conf_int, boot_felm_c_fe$conf_int, tolerance = 0.1)
 
 
